@@ -9,7 +9,7 @@ model.matrix.gls <- function(object, ...) {
 }
 
 #' @importFrom nlme getResponse getData getCovariateFormula
-#' @importFrom sjmisc get_label
+#' @importFrom sjlabelled get_label
 #' @export
 model.frame.gls <- function(formula, ...) {
   if (!inherits(formula, "gls")) {
@@ -18,7 +18,7 @@ model.frame.gls <- function(formula, ...) {
   } else {
     y <- nlme::getResponse(formula)
     mf <- cbind(y, nlme::getData(formula)[, all.vars(nlme::getCovariateFormula(formula))])
-    colnames(mf)[1] <- sjmisc::get_label(y, def.value = "Response")
+    colnames(mf)[1] <- sjlabelled::get_label(y, def.value = "Response")
     return(mf)
   }
 }
@@ -26,20 +26,45 @@ model.frame.gls <- function(formula, ...) {
 
 #' @importFrom tibble tibble
 #' @importFrom stats coef vcov pnorm
+#' @importFrom dplyr case_when
 #' @export
-print.svyglm.nb <- function(x, ...) {
-  print(tidy_svyglm.nb(x)[-1, ], ...)
+print.svyglm.nb <- function(x, se = c("robust", "model"), digits = 4, ...) {
+  se <- match.arg(se)
+  sm <- tidy_svyglm.nb(x, digits, v_se = se)[-1, -2]
+
+  pan <- dplyr::case_when(
+    sm$p.value < 0.001 ~ "<0.001 ***",
+    sm$p.value < 0.01 ~ sprintf("%.*f ** ", digits, sm$p.value),
+    sm$p.value < 0.05 ~ sprintf("%.*f *  ", digits, sm$p.value),
+    sm$p.value < 0.1 ~ sprintf("%.*f .  ", digits, sm$p.value),
+    TRUE ~  sprintf("%.*f    ", digits, sm$p.value)
+  )
+
+  sm$p.value <- pan
+  print(sm, ...)
+  message(sprintf("Showing %s standard errors on link-scale (untransformed).", se))
 }
 
-tidy_svyglm.nb <- function(x, digits = 4) {
+
+#' @importFrom stats qnorm coef pnorm vcov
+tidy_svyglm.nb <- function(x, digits = 4, v_se = c("robust", "model")) {
+  v_se <- match.arg(v_se)
+
   if (!isNamespaceLoaded("survey"))
     requireNamespace("survey", quietly = TRUE)
+
+  # keep original value, not rounded
+  est <- stats::coef(x)
+  se <- sqrt(diag(stats::vcov(x, stderr = v_se)))
+
   tibble::tibble(
     term = substring(names(stats::coef(x)), 5),
-    estimate = round(stats::coef(x), digits),
-    irr = round(exp(estimate), digits),
-    std.error = round(sqrt(diag(stats::vcov(x, stderr = "robust"))), digits),
-    p.value = round(2 * stats::pnorm(abs(estimate / std.error), lower.tail = FALSE), digits)
+    estimate = round(est, digits),
+    irr = round(exp(est), digits),
+    std.error = round(se, digits),
+    conf.low = round(exp(est - stats::qnorm(.975) * se), digits),
+    conf.high = round(exp(est + stats::qnorm(.975) * se), digits),
+    p.value = round(2 * stats::pnorm(abs(est / se), lower.tail = FALSE), digits)
   )
 }
 
@@ -248,10 +273,15 @@ print.sj_resample <- function(x, ...) {
 #' @export
 print.se.icc.lme4 <- function(x, ...) {
   cat("Standard Error of ICC\n")
-  cat(sprintf("      Model: %s\n", x$result$model))
-  cat(sprintf("        ICC: %.4f\n", x$result$icc))
-  cat(sprintf("  std. err.: %.4f\n", x$result$std.err))
-  cat(sprintf("    p-value: %.4f\n", x$result$p.value))
+  cat(sprintf("      Model: %s\n", x$result$model[[1]]))
+
+  for (i in 1:nrow(x$result)) {
+    cat(sprintf("        ICC: %.4f\n", x$result$icc[i]))
+    cat(sprintf("  std. err.: %.4f\n", x$result$std.err[i]))
+    cat(sprintf("    p-value: %.4f\n", x$result$p.value[i]))
+
+    if (i < nrow(x$result)) cat("\n")
+  }
 }
 
 
