@@ -36,19 +36,25 @@
 #'
 #' @importFrom stats na.omit wilcox.test kruskal.test
 #' @importFrom coin wilcox_test pvalue statistic
-#' @importFrom sjmisc to_value get_labels recode_to
+#' @importFrom sjmisc recode_to
+#' @importFrom sjlabelled get_labels as_numeric
 #' @export
 mwu <- function(x, grp, distribution = "asymptotic", weight.by = NULL) {
   # coerce factor and character to numeric
-  if (is.factor(grp) || is.character(grp)) grp <- sjmisc::to_value(grp)
+  if (is.factor(grp) || is.character(grp)) grp <- sjlabelled::as_numeric(grp)
+
   # group "counter" (index) should start with 1, not 0
   if (min(grp, na.rm = TRUE) < 1) grp <- sjmisc::recode_to(grp, lowest = 1)
+
   # retrieve unique group values. need to iterate all values
   grp_values <- sort(unique(stats::na.omit(grp)))
+
   # length of value range
   cnt <- length(grp_values)
-  labels <- sjmisc::get_labels(grp, attr.only = F, include.values = NULL,
-                               include.non.labelled = T)
+  labels <- sjlabelled::get_labels(
+    grp, attr.only = F, include.values = NULL, include.non.labelled = T
+  )
+
   df <- data.frame()
   for (i in seq_len(cnt)) {
     for (j in i:cnt) {
@@ -74,10 +80,13 @@ mwu <- function(x, grp, distribution = "asymptotic", weight.by = NULL) {
         if (is.null(weight.by)) {
           wt <- coin::wilcox_test(xsub ~ ysub, distribution = distribution)
         } else {
-          wt <- coin::wilcox_test(xsub ~ ysub,
-                                  distribution = distribution,
-                                  weight.by = as.formula("~wsub"))
+          wt <- coin::wilcox_test(
+            xsub ~ ysub,
+            distribution = distribution,
+            weight.by = as.formula("~wsub")
+          )
         }
+
         # compute statistics
         u <- as.numeric(coin::statistic(wt, type = "linear"))
         z <- as.numeric(coin::statistic(wt, type = "standardized"))
@@ -99,6 +108,7 @@ mwu <- function(x, grp, distribution = "asymptotic", weight.by = NULL) {
       }
     }
   }
+
   # convert variables
   df[["grp1"]] <- as.numeric(as.character(df[["grp1"]]))
   df[["grp2"]] <- as.numeric(as.character(df[["grp2"]]))
@@ -126,6 +136,7 @@ mwu <- function(x, grp, distribution = "asymptotic", weight.by = NULL) {
 
   # replace 0.001 with <0.001
   levels(tab.df$p)[which(levels(tab.df$p) == "0.001")] <- "<0.001"
+
   # return both data frames
   structure(class = c("mwu", "sj_mwu"), list(df = df, tab.df = tab.df, data = data.frame(x, grp)))
 }
